@@ -1,11 +1,8 @@
 from PyQt5.QtWidgets import QFrame, QHBoxLayout 
 from PyQt5.QtCore import Qt, QMimeData, QDir, pyqtSignal
-from PyQt5.QtGui import QDrag, QPixmap, QPainter,QColor
+from PyQt5.QtGui import QDrag, QPixmap, QPainter, QColor
 import sys, logging
 from Pythonic.workingarea import WorkingArea
-from Pythonic.menubar import MenuBar
-from Pythonic.executor import Executor
-from Pythonic.top_menubar import topMenuBar
 from Pythonic.mastertool import MasterTool
 
 
@@ -56,7 +53,6 @@ class BinanceTools(QFrame):
         mimeData.setText(child.type)
 
         drag = QDrag(self)
-        #drag.setPixmap(QPixmap('images/icon.png'))
         drag.setPixmap(child.pixmap())
         drag.setMimeData(mimeData)
         drag.setHotSpot(event.pos() - child.pos())
@@ -76,7 +72,7 @@ class BinanceTools(QFrame):
             child.setPixmap(pixmap)
 
     def register_tools(self):
-        logging.debug('register_tools() called BinanceTools')
+        logging.debug('BinanceTools::register_tools() called')
         self.reg_tool.emit(self.scheduler.toolData())
         self.reg_tool.emit(self.ohlc.toolData())
         self.reg_tool.emit(self.order.toolData())
