@@ -1,13 +1,11 @@
-from PyQt5.QtWidgets import (QLabel, QWidget, QVBoxLayout, QHBoxLayout, QSizePolicy, QStyleOption, QStyle,
-                                QPushButton, QTextEdit, QMainWindow)
-from PyQt5.QtGui import QPixmap, QPainter, QPen, QFont
-from PyQt5.QtCore import Qt, QCoreApplication, pyqtSignal, QPoint, QRect
+from PyQt5.QtWidgets import QLabel, QWidget, QVBoxLayout, QPushButton, QTextEdit
+from PyQt5.QtGui import QFont
+from PyQt5.QtCore import Qt, pyqtSignal
 from PyQt5.QtCore import QCoreApplication as QC
-from PyQt5.QtCore import QThread
-from elementmaster import alphabet
 import multiprocessing as mp
-from elementeditor import ElementEditor
 import logging, sys, time, traceback
+from Pythonic.elementmaster import alphabet
+from Pythonic.elementeditor import ElementEditor
 
 
 class DebugWindow(QWidget):
