@@ -26,7 +26,12 @@ class StorageBar(QWidget):
         self.box_frame.setContentsMargins(0, 0, 0, 0)
         self.icon_bar = QWidget()
         self.icon_bar_spacer = QWidget()
-        self.icon_bar.setStyleSheet('background-color: rgba(204, 51, 0, 0.5)')
+        self.icon_bar.setStyleSheet('background-color: rgba(77, 103, 125, 0.5);\
+                border-radius: 10px')
+        #self.icon_bar.setStyleSheet('background-color: \
+        #        qlineargradient(x1:0.5 y1:0, x2:0.5 y2:1, stop:0 #646464, stop:1 #366a97);\
+        #        border-radius: 10px')
+
 
         policy = QSizePolicy()
         policy.setRetainSizeWhenHidden(True)
@@ -64,7 +69,8 @@ class StorageBar(QWidget):
 
     def storeSignal(self, row, column):
 
-        logging.debug('storeSignal() called - delete row {} - column {}'.format(row, column))
+        logging.debug('StorageBar::storeSignal() called - delete row {} - column {}'.format(
+            row, column))
         self.addBox()
 
         element = self.parent().grid.itemAtPosition(row, column).widget()
@@ -80,13 +86,14 @@ class StorageBar(QWidget):
 
     def saveConfig(self, row, column):
 
-        logging.debug('saveConfig() called')
+        logging.debug('StorageBar::saveConfig() called')
 
         element = self.parent().grid.itemAtPosition(row, column).widget()
         return element.config
 
     def returnConfig(self):
 
+        logging.debug('StorageBar::returnConfig() called')
         self.tmp_element.destroy()
         return self.tmp_config
     
